# SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later

import sys
from io import BytesIO

import atheris
from test_utils import is_expected_exception

with atheris.instrument_imports():
    from dulwich.config import ConfigFile


def TestOneInput(data) -> int | None:
    try:
        ConfigFile.from_file(BytesIO(data))
    except ValueError as e:
        expected_exceptions = [
            "without section",
            "invalid variable name",
            "expected trailing ]",
            "invalid section name",
            "Invalid subsection",
            "escape character",
            "missing end quote",
        ]
        if is_expected_exception(expected_exceptions, e):
            return -1
        else:
            raise e


def main() -> None:
    atheris.Setup(sys.argv, TestOneInput)
    atheris.Fuzz()


if __name__ == "__main__":
    main()



# test_config.py -- property tests for config.py
# Copyright (C) 2026 The Dulwich contributors
#
# SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later
# Dulwich is dual-licensed under the Apache License, Version 2.0 and the GNU
# General Public License as published by the Free Software Foundation; version 2.0
# or (at your option) any later version. You can redistribute it and/or
# modify it under the terms of either of these two licenses.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# You should have received a copy of the licenses; if not, see
# <http://www.gnu.org/licenses/> for a copy of the GNU General Public License
# and <http://www.apache.org/licenses/LICENSE-2.0> for a copy of the Apache
# License, Version 2.0.
#

"""Property tests for reading and writing configuration files."""

import os
from io import BytesIO

from hypothesis import given, settings
from hypothesis import strategies as st

from dulwich.config import ConfigFile
from tests import TestCase

EXPECTED_PARSE_ERRORS = (
    "without section",
    "invalid variable name",
    "expected trailing ]",
    "invalid section name",
    "Invalid subsection",
    "escape character",
    "missing end quote",
)


settings.register_profile(
    "deterministic", max_examples=50, deadline=None, derandomize=True
)
settings.register_profile("ci", max_examples=50, deadline=None, derandomize=True)
settings.register_profile(
    "local-deep", max_examples=1000, deadline=None, derandomize=True
)
settings.load_profile(os.environ.get("HYPOTHESIS_PROFILE", "deterministic"))

section_names = st.text(
    alphabet="abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-",
    min_size=1,
    max_size=12,
).map(lambda value: value.encode("ascii"))

subsection_names = st.text(
    alphabet="abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-._/",
    min_size=1,
    max_size=16,
).map(lambda value: value.encode("ascii"))

variable_names = st.text(
    alphabet="abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-",
    min_size=1,
    max_size=12,
).map(lambda value: value.encode("ascii"))

values = st.text(
    alphabet=(
        'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789 -_./:#\t\n\\"'
    ),
    max_size=32,
).map(lambda value: value.encode("ascii"))

sections = st.tuples(
    section_names,
    st.one_of(st.none(), subsection_names),
    st.dictionaries(variable_names, values, min_size=1, max_size=6),
)

configs = st.lists(sections, min_size=0, max_size=6)


def _config_from_sections(
    sections: list[tuple[bytes, bytes | None, dict[bytes, bytes]]],
) -> ConfigFile:
    config = ConfigFile()
    for section_name, subsection_name, variables in sections:
        section = (
            (section_name,)
            if subsection_name is None
            else (section_name, subsection_name)
        )
        for key, value in variables.items():
            config.set(section, key, value)
    return config


class ConfigFilePropertyTests(TestCase):
    """Property tests for ConfigFile."""

    @given(st.binary(max_size=512))
    def test_binary_input_only_raises_expected_parse_errors(self, data: bytes) -> None:
        """Check that arbitrary bytes only raise expected parse errors."""
        try:
            ConfigFile.from_file(BytesIO(data))
        except ValueError as exc:
            self.assertTrue(
                any(message in str(exc) for message in EXPECTED_PARSE_ERRORS),
                str(exc),
            )

    @given(configs)
    def test_write_roundtrip_preserves_effective_config(
        self,
        generated_sections: list[tuple[bytes, bytes | None, dict[bytes, bytes]]],
    ) -> None:
        """Check that writing and reading preserves generated configs."""
        config = _config_from_sections(generated_sections)

        output = BytesIO()
        config.write_to_file(output)

        reparsed = ConfigFile.from_file(BytesIO(output.getvalue()))
        self.assertEqual(config, reparsed)



# SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later

import stat
import sys
from io import BytesIO

import atheris

with atheris.instrument_imports():
    # We instrument `test_utils` as well, so it doesn't block coverage analysis in Fuzz Introspector:
    from test_utils import EnhancedFuzzedDataProvider, is_expected_exception

    from dulwich.errors import ObjectFormatException
    from dulwich.objects import S_IFGITLINK, Blob, Commit, Tree
    from dulwich.patch import write_tree_diff
    from dulwich.repo import (
        InvalidUserIdentity,
        MemoryRepo,
    )


def TestOneInput(data) -> int | None:
    fdp = EnhancedFuzzedDataProvider(data)
    repo = MemoryRepo()
    blob = Blob.from_string(fdp.ConsumeRandomBytes())
    tree = Tree()
    tree.add(
        fdp.ConsumeRandomBytes(),
        fdp.PickValueInList([stat.S_IFREG, stat.S_IFLNK, stat.S_IFDIR, S_IFGITLINK]),
        blob.id,
    )
    commit = Commit()
    commit.tree = tree.id
    commit.author = fdp.ConsumeRandomBytes()
    commit.committer = fdp.ConsumeRandomBytes()
    commit.commit_time = fdp.ConsumeRandomInt()
    commit.commit_timezone = fdp.ConsumeRandomInt()
    commit.author_time = fdp.ConsumeRandomInt()
    commit.author_timezone = fdp.ConsumeRandomInt()
    commit.message = fdp.ConsumeRandomBytes()

    object_store = repo.object_store

    try:
        object_store.add_object(blob)
        object_store.add_object(tree)
        object_store.add_object(commit)
    except (InvalidUserIdentity, ObjectFormatException):
        return -1
    except ValueError as e:
        expected_exceptions = [
            "subsection not found",
            "Unable to handle non-minute offset",
        ]
        if is_expected_exception(expected_exceptions, e):
            return -1
        else:
            raise e

    commit2 = Commit()
    commit2.tree = tree.id
    commit2.parents = [commit.id]
    commit2.author = commit.author
    commit2.committer = commit.committer
    commit2.commit_time = fdp.ConsumeRandomInt()
    commit2.commit_timezone = fdp.ConsumeRandomInt()
    commit2.author_time = fdp.ConsumeRandomInt()
    commit2.author_timezone = fdp.ConsumeRandomInt()
    commit2.message = fdp.ConsumeRandomBytes()

    try:
        blob.data = fdp.ConsumeRandomBytes()
        repo.object_store.add_object(blob)
        repo.object_store.add_object(tree)
        repo.object_store.add_object(commit2)
        out = BytesIO()
        write_tree_diff(out, repo.object_store, commit.tree, tree.id)
    except (InvalidUserIdentity, ObjectFormatException):
        return -1
    except ValueError as e:
        expected_exceptions = [
            "Unable to handle non-minute offset",
        ]
        if is_expected_exception(expected_exceptions, e):
            return -1
        else:
            raise e


def main() -> None:
    atheris.Setup(sys.argv, TestOneInput)
    atheris.Fuzz()


if __name__ == "__main__":
    main()



# SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later

import os
import sys
import tempfile

import atheris

with atheris.instrument_imports():
    # We instrument `test_utils` as well, so it doesn't block coverage analysis in Fuzz Introspector:
    from test_utils import EnhancedFuzzedDataProvider, is_expected_exception

    from dulwich.repo import (
        InvalidUserIdentity,
        Repo,
    )


def TestOneInput(data) -> int | None:
    fdp = EnhancedFuzzedDataProvider(data)
    with tempfile.TemporaryDirectory() as temp_dir:
        repo = Repo.init(temp_dir)
        repo.set_description(fdp.ConsumeRandomBytes())
        repo.get_description()

        try:
            # Generate a minimal set of files based on fuzz data to minimize I/O operations.
            file_names = [
                f"File{i}{fdp.ConsumeRandomString(without_surrogates=True)}"
                for i in range(min(3, fdp.ConsumeIntInRange(1, 3)))
            ]
            for file in file_names:
                with open(os.path.join(temp_dir, file), "wb") as f:
                    f.write(fdp.ConsumeRandomBytes())
        except (ValueError, OSError):
            # Exit early if the fuzzer generates an invalid filename.
            return -1

        try:
            repo.get_worktree().stage(file_names)
            repo.get_worktree().commit(
                message=fdp.ConsumeRandomBytes(),
                committer=fdp.ConsumeRandomBytes(),
                author=fdp.ConsumeRandomBytes(),
                commit_timestamp=fdp.ConsumeRandomInt(),
                commit_timezone=fdp.ConsumeRandomInt(),
                author_timestamp=fdp.ConsumeRandomInt(),
                author_timezone=fdp.ConsumeRandomInt(),
            )
        except InvalidUserIdentity:
            return -1
        except ValueError as e:
            if is_expected_exception(["Unable to handle non-minute offset"], e):
                return -1
            else:
                raise e


def main() -> None:
    atheris.Setup(sys.argv, TestOneInput)
    atheris.Fuzz()


if __name__ == "__main__":
    main()



# hooks.py -- for dealing with git hooks
# Copyright (C) 2012-2013 Jelmer Vernooij and others.
#
# SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later
# Dulwich is dual-licensed under the Apache License, Version 2.0 and the GNU
# General Public License as published by the Free Software Foundation; version 2.0
# or (at your option) any later version. You can redistribute it and/or
# modify it under the terms of either of these two licenses.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# You should have received a copy of the licenses; if not, see
# <http://www.gnu.org/licenses/> for a copy of the GNU General Public License
# and <http://www.apache.org/licenses/LICENSE-2.0> for a copy of the Apache
# License, Version 2.0.
#

"""Access to hooks."""

__all__ = [
    "CommitMsgShellHook",
    "Hook",
    "PostCommitShellHook",
    "PostReceiveShellHook",
    "PreCommitShellHook",
    "PreReceiveShellHook",
    "ShellHook",
    "UpdateShellHook",
]

import os
import subprocess
from collections.abc import Callable, Sequence
from typing import Any

from .errors import HookError


class Hook:
    """Generic hook object."""

    def execute(self, *args: Any) -> Any:  # noqa: ANN401
        """Execute the hook with the given args.

        Args:
          args: argument list to hook
        Raises:
          HookError: hook execution failure
        Returns:
          a hook may return a useful value
        """
        raise NotImplementedError(self.execute)


class ShellHook(Hook):
    """Hook by executable file.

    Implements standard githooks(5) [0]:

    [0] http://www.kernel.org/pub/software/scm/git/docs/githooks.html
    """

    def __init__(
        self,
        name: str,
        path: str,
        numparam: int,
        pre_exec_callback: Callable[..., Any] | None = None,
        post_exec_callback: Callable[..., Any] | None = None,
        cwd: str | None = None,
    ) -> None:
        """Setup shell hook definition.

        Args:
          name: name of hook for error messages
          path: absolute path to executable file
          numparam: number of requirements parameters
          pre_exec_callback: closure for setup before execution
            Defaults to None. Takes in the variable argument list from the
            execute functions and returns a modified argument list for the
            shell hook.
          post_exec_callback: closure for cleanup after execution
            Defaults to None. Takes in a boolean for hook success and the
            modified argument list and returns the final hook return value
            if applicable
          cwd: working directory to switch to when executing the hook
        """
        self.name = name
        self.filepath = path
        self.numparam = numparam

        self.pre_exec_callback = pre_exec_callback
        self.post_exec_callback = post_exec_callback

        self.cwd = cwd

    def execute(self, *args: Any) -> Any:  # noqa: ANN401
        """Execute the hook with given args."""
        if len(args) != self.numparam:
            raise HookError(
                f"Hook {self.name} executed with wrong number of args. Expected {self.numparam}. Saw {len(args)}. args: {args}"
            )

        if self.pre_exec_callback is not None:
            args = self.pre_exec_callback(*args)

        try:
            ret = subprocess.call(
                [os.path.relpath(self.filepath, self.cwd), *list(args)], cwd=self.cwd
            )
            if ret != 0:
                if self.post_exec_callback is not None:
                    self.post_exec_callback(0, *args)
                raise HookError(f"Hook {self.name} exited with non-zero status {ret}")
            if self.post_exec_callback is not None:
                return self.post_exec_callback(1, *args)
        except FileNotFoundError:  # no file. silent failure.
            if self.post_exec_callback is not None:
                self.post_exec_callback(0, *args)


class PreCommitShellHook(ShellHook):
    """pre-commit shell hook."""

    def __init__(self, cwd: str, controldir: str) -> None:
        """Initialize pre-commit hook.

        Args:
            cwd: Working directory for hook execution
            controldir: Path to the git control directory (.git)
        """
        filepath = os.path.join(controldir, "hooks", "pre-commit")

        ShellHook.__init__(self, "pre-commit", filepath, 0, cwd=cwd)


class PostCommitShellHook(ShellHook):
    """post-commit shell hook."""

    def __init__(self, controldir: str) -> None:
        """Initialize post-commit hook.

        Args:
            controldir: Path to the git control directory (.git)
        """
        filepath = os.path.join(controldir, "hooks", "post-commit")

        ShellHook.__init__(self, "post-commit", filepath, 0, cwd=controldir)


class CommitMsgShellHook(ShellHook):
    """commit-msg shell hook."""

    def __init__(self, controldir: str) -> None:
        """Initialize commit-msg hook.

        Args:
            controldir: Path to the git control directory (.git)
        """
        filepath = os.path.join(controldir, "hooks", "commit-msg")

        def prepare_msg(*args: bytes) -> tuple[str, ...]:
            import tempfile

            (fd, path) = tempfile.mkstemp()

            with os.fdopen(fd, "wb") as f:
                f.write(args[0])

            return (path,)

        def clean_msg(success: int, *args: str) -> bytes | None:
            if success:
                with open(args[0], "rb") as f:
                    new_msg = f.read()
                os.unlink(args[0])
                return new_msg
            os.unlink(args[0])
            return None

        ShellHook.__init__(
            self, "commit-msg", filepath, 1, prepare_msg, clean_msg, controldir
        )


class PostReceiveShellHook(ShellHook):
    """post-receive shell hook."""

    def __init__(self, controldir: str) -> None:
        """Initialize post-receive hook.

        Args:
            controldir: Path to the git control directory (.git)
        """
        self.controldir = controldir
        filepath = os.path.join(controldir, "hooks", "post-receive")
        ShellHook.__init__(self, "post-receive", path=filepath, numparam=0)

    def execute(
        self, client_refs: Sequence[tuple[bytes, bytes, bytes]]
    ) -> bytes | None:
        """Execute the post-receive hook.

        Args:
            client_refs: List of tuples containing (old_sha, new_sha, ref_name)
                        for each updated reference

        Returns:
            Output from the hook execution or None if hook doesn't exist

        Raises:
            HookError: If hook execution fails
        """
        # do nothing if the script doesn't exist
        if not os.path.exists(self.filepath):
            return None

        try:
            env = os.environ.copy()
            env["GIT_DIR"] = self.controldir

            p = subprocess.Popen(
                self.filepath,
                stdin=subprocess.PIPE,
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE,
                env=env,
            )

            # client_refs is a list of (oldsha, newsha, ref)
            in_data = b"\n".join([b" ".join(ref) for ref in client_refs])

            out_data, err_data = p.communicate(in_data)

            if (p.returncode != 0) or err_data:
                err_msg = (
                    f"post-receive exit code: {p.returncode}\n"
                    f"stdout:\n{out_data.decode('utf-8', 'backslashreplace')}\n"
                    f"stderr:\n{err_data.decode('utf-8', 'backslashreplace')}"
                )
                raise HookError(err_msg)
            return out_data
        except OSError as err:
            raise HookError(repr(err)) from err


class PreReceiveShellHook(ShellHook):
    """pre-receive shell hook."""

    def __init__(self, controldir: str) -> None:
        """Initialize pre-receive hook.

        Args:
            controldir: Path to the git control directory (.git)
        """
        self.controldir = controldir
        filepath = os.path.join(controldir, "hooks", "pre-receive")
        ShellHook.__init__(self, "pre-receive", path=filepath, numparam=0)

    def execute(
        self, client_refs: Sequence[tuple[bytes, bytes, bytes]]
    ) -> tuple[bytes, bytes]:
        """Execute the pre-receive hook.

        Args:
            client_refs: List of tuples containing (old_sha, new_sha, ref_name)
                        for each reference to be updated

        Returns:
            Tuple of (stdout, stderr) from hook execution

        Raises:
            HookError: If hook execution fails (exits with non-zero status)
        """
        # do nothing if the script doesn't exist
        if not os.path.exists(self.filepath):
            return (b"", b"")

        try:
            env = os.environ.copy()
            env["GIT_DIR"] = self.controldir

            p = subprocess.Popen(
                self.filepath,
                stdin=subprocess.PIPE,
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE,
                env=env,
            )

            # client_refs is a list of (oldsha, newsha, ref)
            in_data = b"\n".join([b" ".join(ref) for ref in client_refs])

            out_data, err_data = p.communicate(in_data)

            if p.returncode != 0:
                raise HookError(
                    f"pre-receive hook exited with status {p.returncode}: {err_data.decode('utf-8', 'backslashreplace')}"
                )
            return (out_data, err_data)
        except OSError as err:
            raise HookError(repr(err)) from err


class UpdateShellHook(ShellHook):
    """update shell hook."""

    def __init__(self, controldir: str) -> None:
        """Initialize update hook.

        Args:
            controldir: Path to the git control directory (.git)
        """
        self.controldir = controldir
        filepath = os.path.join(controldir, "hooks", "update")
        ShellHook.__init__(self, "update", path=filepath, numparam=3)

    def execute(
        self, ref_name: bytes, old_sha: bytes, new_sha: bytes
    ) -> tuple[bytes, bytes]:
        """Execute the update hook for a single ref.

        Args:
            ref_name: Name of the reference being updated
            old_sha: Old SHA of the reference
            new_sha: New SHA of the reference

        Returns:
            Tuple of (stdout, stderr) from hook execution

        Raises:
            HookError: If hook execution fails (exits with non-zero status)
        """
        # do nothing if the script doesn't exist
        if not os.path.exists(self.filepath):
            return (b"", b"")

        try:
            env = os.environ.copy()
            env["GIT_DIR"] = self.controldir

            p = subprocess.Popen(
                [
                    self.filepath,
                    ref_name.decode("utf-8", "backslashreplace"),
                    old_sha.decode("utf-8", "backslashreplace"),
                    new_sha.decode("utf-8", "backslashreplace"),
                ],
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE,
                env=env,
            )

            out_data, err_data = p.communicate()

            if p.returncode != 0:
                raise HookError(
                    f"update hook exited with status {p.returncode}: {err_data.decode('utf-8', 'backslashreplace')}"
                )
            return (out_data, err_data)
        except OSError as err:
            raise HookError(repr(err)) from err



# SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later

import atheris  # pragma: no cover


@atheris.instrument_func
def is_expected_exception(
    error_message_list: list[str], exception: Exception
) -> bool:  # pragma: no cover
    """Checks if the message of a given exception matches any of the expected error messages.

    Args:
         error_message_list (List[str]): A list of error message substrings to check against the exception's message.
         exception (Exception): The exception object raised during execution.

    Returns:
      bool: True if the exception's message contains any of the substrings from the error_message_list, otherwise False.
    """
    for error in error_message_list:
        if error in str(exception):
            return True
    return False


class EnhancedFuzzedDataProvider(atheris.FuzzedDataProvider):  # pragma: no cover
    """Extends atheris.FuzzedDataProvider to offer additional methods to make fuzz testing slightly more DRY."""

    def __init__(self, data) -> None:
        """Initializes the EnhancedFuzzedDataProvider with fuzzing data from the argument provided to TestOneInput.

        Args:
            data (bytes): The binary data used for fuzzing.
        """
        super().__init__(data)

    def ConsumeRemainingBytes(self) -> bytes:
        """Consume the remaining bytes in the bytes container.

        Returns:
          bytes: Zero or more bytes.
        """
        return self.ConsumeBytes(self.remaining_bytes())

    def ConsumeRandomBytes(self, max_length=None) -> bytes:
        """Consume a random count of bytes from the bytes container.

        Args:
          max_length (int, optional): The maximum length of the string. Defaults to the number of remaining bytes.

        Returns:
          bytes: Zero or more bytes.
        """
        if max_length is None:
            max_length = self.remaining_bytes()
        else:
            max_length = min(max_length, self.remaining_bytes())

        return self.ConsumeBytes(self.ConsumeIntInRange(0, max_length))

    def ConsumeRandomString(self, max_length=None, without_surrogates=False) -> str:
        """Consume bytes to produce a Unicode string.

        Args:
          max_length (int, optional): The maximum length of the string. Defaults to the number of remaining bytes.
          without_surrogates (bool, optional): If True, never generate surrogate pair characters. Defaults to False.

        Returns:
         str: A Unicode string.
        """
        if max_length is None:
            max_length = self.remaining_bytes()
        else:
            max_length = min(max_length, self.remaining_bytes())

        count = self.ConsumeIntInRange(0, max_length)

        if without_surrogates:
            return self.ConsumeUnicodeNoSurrogates(count)
        else:
            return self.ConsumeUnicode(count)

    def ConsumeRandomInt(self, minimum=0, maximum=1234567890) -> int:
        """Consume bytes to produce an integer.

        Args:
          minimum (int, optional): The minimum value of the integer. Defaults to 0.
          maximum (int, optional): The maximum value of the integer. Defaults to 1234567890.

        Returns:
          int: An integer.
        """
        return self.ConsumeIntInRange(minimum, maximum)



# SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later

import sys
from io import BytesIO

import atheris

with atheris.instrument_imports():
    # We instrument `test_utils` as well, so it doesn't block coverage analysis in Fuzz Introspector:
    from test_utils import EnhancedFuzzedDataProvider, is_expected_exception

    from dulwich.bundle import Bundle, read_bundle, write_bundle
    from dulwich.pack import PackData, write_pack_objects


def TestOneInput(data) -> int | None:
    fdp = EnhancedFuzzedDataProvider(data)
    bundle = Bundle()
    bundle.version = fdp.PickValueInList([2, 3, None])
    bundle.references = {fdp.ConsumeRandomString(): fdp.ConsumeBytes(20)}
    bundle.prerequisites = [(fdp.ConsumeBytes(20), fdp.ConsumeRandomBytes())]
    bundle.capabilities = {
        fdp.ConsumeRandomString(): fdp.ConsumeRandomString(),
    }

    b = BytesIO()
    write_pack_objects(b.write, [])
    b.seek(0)
    bundle.pack_data = PackData.from_file(b)

    # Test __repr__ method
    _ = repr(bundle)

    try:
        bundle_file = BytesIO()
        write_bundle(bundle_file, bundle)
        _ = read_bundle(bundle_file)
    except (AttributeError, UnicodeEncodeError, AssertionError) as e:
        expected_exceptions = [
            "'bytes' object has no attribute 'encode'",
            "surrogates not allowed",
            "unsupported bundle format header",
        ]
        if is_expected_exception(expected_exceptions, e):
            return -1
        else:
            raise e


def main() -> None:
    atheris.Setup(sys.argv, TestOneInput)
    atheris.Fuzz()


if __name__ == "__main__":
    main()
